==> fluxbox-0.9.13.tar.bz2: fluxbox-0.9.13/nls/cs_CZ/Translation.m <==
$ codeset=ISO-8859-2

$set 1 #Align

1 Dole uprosted
2 Dole vlevo
3 Dole vpravo
4 Horizontln
5 Vlevo
6 Vlevo dole
7 Vlevo uprosted
8 Vlevo nahoe
9 Relativn
10 Vpravo
11 Vpravo dole
12 Vpravo uprosted
13 Vpravo nahoe
14 Nahoe uprosted
15 Nahoe vlevo
16 Nahoe vpravo
17 Vertikln

$set 2 #BaseDisplay

1 Ukonuji... zaznamenvm pd aplikace\n
2 Vypnm\n
3 %s:      zachycen signl %d\n

$set 3 #Common

1 Alpha
2 Automaticky skrvat
3 Zkompilovno
4 Nastaven kompiltoru
5 Kompiltor
6 Verze kompiltoru
7 Soubor init
8 Soubor s definic klves
9 Soubor s definic menu
10 Soubor se stylem
11 Implicitn
12 neaktivn
13 Chyba
14 Verze Fluxboxu
15 Maximalizovat pes vechna okna
16 Viditeln

$set 4 #Configmenu

1 Antialiasovan fonty
2 Automatick vyzvednut okna
3 Vyzvednut okna kliknutm
4 Zamen okna kliknutm
5 Odekorovat pomjiv okna
6 Pepnn ploch kolekem myi
7 Zamit okno pi zmn plochy
8 Model zamen okna
9 Zamit nov okna
10 Pln maximalizace
11 Dithering obrazu
12 Pohyb okna i s obsahem
13 sten nedbal zamen okna
14 Nedbal zamen okna
15 Prolnn ploch
16 Vynutit pseudo-prhlednost
17 Alpha menu
18 Prhlednost
19 Alpha zamenho okna
20 Alpha nezamenho okna

$set 5 #Ewmh

1 Fatal: Out of memory, can't allocate for EWMH client list

$set 6 #FbTkError

1 Warning! Height > 3200 setting Height = 3200
2 Warning! Width > 3200 setting Width = 3200
3 Warning: can't load fallback font
4 Allocation error.
5 Error creating pixmap
6 Cant create XImage
7 Failed to read
8 Warning: Failed to find valid format for alpha.
9 Warning: Failed to create alpha picture.
10 Warning: Failed to create alpha pixmap.
11 Failed to find format for screen(%d)
12 Out of memory
13 Out of memory while allocating blue buffer.
14 Out of memory while allocating green buffer.
15 Out of memory while allocating red buffer.
16 Failed to read theme item
17 unsupported visual
18 Setting default value

$set 7 #Fluxbox

1 rc filename is invalid!
2 Failed to load groupfile
3 Failed to load database
4 Retrying with
5 Warning! Could not find screen to map window on!
6 Can't create %s directory
7 Couldn't find screens to manage.\nMake sure you don't have another window manager running.
8 Error parsing regular expression
9 Fatal! There can only one instance of fluxbox class.
10 Can not connect to X server.\nMake sure you started X before you start Fluxbox.
11 Warning: X server does not support locale
12 Warning: cannot set locale modifiers

$set 8 #Gnome

1 Fatal: Out of memory, can't allocate for GNOME client list

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 Konfigurace
2 Implicitn menu Fluxboxu
3 Ukonit
4 Minimalizovan
5 Vrstva...
6 On Head...
7 Umstn
8 Znovu nast konfiguraci
9 Restart
10 xterm

$set 11 #Remember

1 Decorace
2 Rozmr
3 Skok na plochu
4 Vrstva
5 Zapamatovat...
6 Pozice
7 Uloit pi zaven
8 Zarolovn
9 Pipendlen
10 Neznm klvesy aplikace
11 Plocha
12 Hlavika

$set 12 #Screen

1 BScreen::BScreen: an error occured while querying the X server.\n	another window manager already running on display
2 W: %4d x H: %4d
3 W: 0000 x H: 0000
4 BScreen::BScreen: managing screen %d using visual 0x%lx, depth %d\n
5 X: %4d x Y: %4d
6 0: 0000 x 0: 0000

$set 13 #Slit

1 Klientsk aplikace
2 Rolovat dol
3 Rolovat nahoru
4 Umstn Slitu
5 Vrstva Slitu
6 Slit on Head
7 Umstn Slitu
8 Slit
9 Uloit SlitList

$set 14 #Toolbar

1 Upravit nzev aktuln plochy
2 Zobrazovat...
3 Vechna okna
4 Zminimalizovan
5 dn
6 Aktuln plocha
7 Zminimalizovan na aktuln ploe
8 Vrstva nstrojov lity
9 Toolbar on Head
10 Umstn nstrojov lity
11 Nstrojov lita
12 ka (% ky obrazovky)
13 Hodiny: 24h
14 Hodiny: 12h
15 Upravit formt hodin
16 Zobrazit obrzky

$set 15 #Window

1 Beze jmna

$set 16 #Windowmenu

1 Zavt
2 Minimalizovat
3 Vrstva
4 Na pozad
5 Maximalizovat
6 Do poped
7 Poslat na ...
8 Zarolovat
9 Pipendlit na vechny plochy
10 Zabt

$set 17 #Workspace

1 Plocha %d
2 Seznam ploch
3 Nov plocha
4 Odstranit posledn

$set 18 #bsetroot

1 %s: error: must specify one of: -solid, -mod, -gradient\n
2 Couldn't create pixmap atoms, giving up!
3 %s 2.0: (c) 1997-2000 Brad Hughes\n\n\
-display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 chyba: '-display' vyaduje argument\n
2 Bad Alloc
3 Bad cast
4 Out of range
5 Runtime error
6 Standard Exception
7 Neznm chyba
8 chyba: '-log' vyaduje argument\n
9 Logovac soubor
10 Loguji do
11 chyba: '-rc' vyaduje argument\n
12 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tpouzije propojen s displejem <string>.\n\
-rc <string>\t\t\tpouzije alternativn soubor zdroj (resource file).\n\
-version\t\t\tzobrazi verzi a skonci.\n\
-info\t\t\t\tzobrazi nektere zajimave informace.\n\
-log <filename>\t\t\tlogovat vstup do souboru <filename>.\n\
-help\t\t\t\tzobraz tuto npovdu a skon.\n\n
13 varovn: nemohu nastavit promnnou prosted 'DISPLAY'

$set 20

1 Nad dokem
2 Naspod
3 Plocha
4 Dok
5 Normln
6 Navrchu

==> fluxbox-1.0rc2.tar.bz2: fluxbox-1.0rc2/nls/cs_CZ/Translation.m <==
$ codeset=ISO-8859-2

$set 1 #Align

1 Dole uprosted
2 Dole vlevo
3 Dole vpravo
4 Horizontln
5 Vlevo
6 Vlevo dole
7 Vlevo uprosted
8 Vlevo nahoe
9 Relativn
10 Vpravo
11 Vpravo dole
12 Vpravo uprosted
13 Vpravo nahoe
14 Nahoe uprosted
15 Nahoe vlevo
16 Nahoe vpravo
17 Vertikln

$set 2 #BaseDisplay

1 Ukonuji... zaznamenvm pd aplikace\n
2 Vypnm\n
3 %s:      zachycen signl %d\n

$set 3 #Common

1 Alpha
2 Automaticky skrvat
3 Zkompilovno
4 Nastaven kompiltoru
5 Kompiltor
6 Verze kompiltoru
7 Soubor init
8 Soubor s definic klves
10 Soubor s definic menu
11 Soubor se stylem
12 Implicitn
13 neaktivn
14 Chyba
15 Verze Fluxboxu
16 Maximalizovat pes vechna okna
18 Viditeln

$set 4 #Configmenu

1 Antialiasovan fonty
2 Automatick vyzvednut okna
3 Vyzvednut okna kliknutm
4 Zamen okna kliknutm
5 Odekorovat pomjiv okna
6 Pepnn ploch kolekem myi
7 Zamit okno pi zmn plochy
8 Model zamen okna
9 Zamit nov okna
10 Pln maximalizace
11 Dithering obrazu
12 Pohyb okna i s obsahem
13 sten nedbal zamen okna
14 Nedbal zamen okna
15 Prolnn ploch
16 Vynutit pseudo-prhlednost
17 Alpha menu
18 Prhlednost
19 Alpha zamenho okna
20 Alpha nezamenho okna

$set 5 #Ewmh

1 Fatal: Out of memory, can't allocate for EWMH client list

$set 6 #FbTkError

1 Warning! Height > 3200 setting Height = 3200
2 Warning! Width > 3200 setting Width = 3200
3 Warning: can't load fallback font
4 Allocation error.
5 Error creating pixmap
6 Cant create XImage
7 Failed to read
8 Warning: Failed to find valid format for alpha.
9 Warning: Failed to create alpha picture.
10 Warning: Failed to create alpha pixmap.
11 Failed to find format for screen(%d)
12 Out of memory
13 Out of memory while allocating blue buffer.
14 Out of memory while allocating green buffer.
15 Out of memory while allocating red buffer.
16 Failed to read theme item
17 unsupported visual
18 Setting default value

$set 7 #Fluxbox

1 rc filename is invalid!
2 Failed to load groupfile
3 Failed to load database
4 Retrying with
5 Warning! Could not find screen to map window on!
6 Can't create %s directory
7 Couldn't find screens to manage.\nMake sure you don't have another window manager running.
8 Error parsing regular expression
9 Fatal! There can only one instance of fluxbox class.
10 Can not connect to X server.\nMake sure you started X before you start Fluxbox.
11 Warning: X server does not support locale
12 Warning: cannot set locale modifiers

$set 8 #Gnome

1 Fatal: Out of memory, can't allocate for GNOME client list

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 Konfigurace
2 Implicitn menu Fluxboxu
3 Ukonit
4 Minimalizovan
5 Vrstva...
6 On Head...
7 Umstn
8 Znovu nast konfiguraci
9 Restart

$set 11 #Remember

1 Decorace
2 Rozmr
3 Skok na plochu
4 Vrstva
5 Zapamatovat...
6 Pozice
7 Uloit pi zaven
8 Zarolovn
9 Pipendlen
10 Neznm klvesy aplikace
11 Plocha
12 Hlavika

$set 12 #Screen

1 BScreen::BScreen: an error occured while querying the X server.\n	another window manager already running on display
2 W: %4d x H: %4d
3 BScreen::BScreen: managing screen %d using visual 0x%lx, depth %d\n

$set 13 #Slit

1 Klientsk aplikace
2 Rolovat dol
3 Rolovat nahoru
4 Umstn Slitu
5 Vrstva Slitu
6 Slit on Head
7 Umstn Slitu
8 Slit
9 Uloit SlitList

$set 14 #Toolbar

1 Upravit nzev aktuln plochy
2 Zobrazovat...
3 Vechna okna
4 Zminimalizovan
5 dn
6 Aktuln plocha
7 Zminimalizovan na aktuln ploe
8 Vrstva nstrojov lity
9 Toolbar on Head
10 Umstn nstrojov lity
11 Nstrojov lita
12 ka (% ky obrazovky)
13 Hodiny: 24h
14 Hodiny: 12h
15 Upravit formt hodin
16 Zobrazit obrzky

$set 15 #Window

1 Beze jmna

$set 16 #Windowmenu

1 Zavt
2 Minimalizovat
3 Vrstva
4 Na pozad
5 Maximalizovat
6 Do poped
7 Poslat na ...
8 Zarolovat
9 Pipendlit na vechny plochy
10 Zabt

$set 17 #Workspace

1 Plocha %d
2 Seznam ploch
3 Nov plocha
4 Odstranit posledn

$set 18 #fbsetroot

1 error: must specify one of: -solid, -mod, -gradient\n
2 Couldn't create pixmap atoms, giving up!
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 chyba: '-display' vyaduje argument
2 Bad Alloc
3 Bad cast
4 Out of range
5 Runtime error
6 Standard Exception
7 Neznm chyba
8 chyba: '-log' vyaduje argument
9 Logovac soubor
10 Loguji do
11 chyba: '-rc' vyaduje argument
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tpouzije propojen s displejem <string>.\n\
-rc <string>\t\t\tpouzije alternativn soubor zdroj (resource file).\n\
-version\t\t\tzobrazi verzi a skonci.\n\
-info\t\t\t\tzobrazi nektere zajimave informace.\n\
-log <filename>\t\t\tlogovat vstup do souboru <filename>.\n\
-help\t\t\t\tzobraz tuto npovdu a skon.\n\n
14 varovn: nemohu nastavit promnnou prosted 'DISPLAY'

$set 20

1 Nad dokem
2 Naspod
3 Plocha
4 Dok
5 Normln
6 Navrchu
